- Each module (i.e. operator, datatype, etc.) includes a `protocol.py` file that specifies the interface for the expected behavior, and a `mixin.py` file that provides a mixin to comply specified protocols.

## Common

- `protocol.py` : Specifies the common behavior.
